#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_COMPARE_EQUAL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_COMPARE_EQUAL_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/compare_equal.hpp>

#endif
